import React, { ReactNode } from 'react';
import { ProTableProps, ProFormInstance, ProDescriptionsProps, ProColumnType } from '@ant-design/pro-components/es';
import { TableDropdown } from '@ant-design/pro-components';
import { _initConfigAxios } from 'next-dev-utils/dist/_request';

declare type ITabMode = 'form' | 'table' | 'descriptions';
declare type ICrudMode = 'list' | 'add' | 'edit' | 'view' | 'delete';
declare type IFilter = {
    page?: number;
    pageSize?: number;
};
declare type IFormCrudState<U = IFilter> = {
    tabMode: ITabMode;
    crudMode: ICrudMode;
    record: Record<string, any>;
    openModalForm?: boolean;
    editLoading?: boolean;
    deleteLoading?: boolean;
    addLoading?: boolean;
    filter: U;
} & Record<string, any>;
declare type Actions<T> = {
    isHideView?: boolean;
    isHideAdd?: boolean;
    isHideDelete?: boolean;
    isShowOptMenu?: boolean;
    moreMenu?: ReactNode[];
    moreOptMenu?: (value: T) => React.ComponentProps<typeof TableDropdown>['menus'];
};
declare type IFormCrud<T extends Record<string, any>, U = IFilter, ValueType = any> = ProTableProps<T, U, ValueType> & {
    onSetMode?: (opt: {
        record: T;
        tabMode: ITabMode;
        crudMode: ICrudMode;
        isFormFinished?: boolean;
    }) => Promise<void>;
    /**
     * required return promise
     */
    onFormAddFinished?: (formValue: T & {
        record: T;
    }) => Promise<any>;
    /**
     * required return promise
     */
    onFormEditFinished?: (formValue: T & {
        record: T;
    }) => Promise<any>;
    onDeleteFinished?: (formValue: T & {
        record: T;
    }) => Promise<any>;
    isDebug?: boolean;
    /**
     * custom record id for delete or detail param
     * @default id
     */
    recordId?: string | number;
    /**
     * all related action props
     */
    actions?: Actions<T>;
    formType?: 'tab' | 'modal';
    form: ProFormInstance<T>;
    texts?: {
        tabAddText?: string;
    };
    requestConfig?: (value: T & {
        record: T;
    } & Record<any, any>) => typeof _initConfigAxios & {
        deleteUrl?: string;
        editUrl?: string;
        editParam?: Partial<U>;
        editMethod?: string;
        getConfig?: {
            requestReturn: {
                data: T[];
                success?: boolean;
                total?: number | undefined;
            };
            url?: string;
            method?: string;
            params?: Partial<T>;
        };
        addConfig?: {
            url?: string;
            method?: string;
            params?: Partial<T>;
        };
    };
    descriptionsProps?: ProDescriptionsProps;
};
declare const dfState: IFormCrudState<IFilter>;
declare function FormCrud<T extends Record<string, any>, U = any, ValueType = ProColumnType>(props: IFormCrud<T, U, ValueType>): JSX.Element;

export { IFormCrud, IFormCrudState, FormCrud as default, dfState };
